@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2017 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -28,13 +28,14 @@
  */
 class KBIBTEXDATA_EXPORT Preamble : public Element
 {
-    Q_PROPERTY(Value value READ value WRITE setValue)
-
 public:
     explicit Preamble(const Value &value = Value());
     Preamble(const Preamble &other);
     ~Preamble() override;
 
+    bool operator==(const Preamble &other) const;
+    bool operator!=(const Preamble &other) const;
+
     /**
      * Assignment operator, working similar to a copy constructor,
      * but overwrites the current object's values.
