@@ -18,12 +18,16 @@
 #ifndef ENCODERLATEX_H
 #define ENCODERLATEX_H
 
+#ifdef HAVE_KF5
 #include "kbibtexio_export.h"
+#endif // HAVE_KF5
 
 #ifdef HAVE_ICU
 #include <unicode/translit.h>
 #endif // HAVE_ICU
 
+#include <QIODevice>
+
 #include "encoder.h"
 
 /**
@@ -48,6 +52,10 @@ public:
     static const EncoderLaTeX &instance();
     ~EncoderLaTeX() override;
 
+#ifdef BUILD_TESTING
+    static bool writeLaTeXTables(QIODevice &output);
+#endif // BUILD_TESTING
+
 protected:
     EncoderLaTeX();
 
@@ -57,7 +65,6 @@ protected:
      * both in text and in math mode by prefixing with a backlash.
      */
     static const QChar encoderLaTeXProtectedSymbols[];
-    static const int encoderLaTeXProtectedSymbolsLen;
 
     /**
      * This data structure keeps individual characters that have
@@ -66,7 +73,6 @@ protected:
      * those have a different purpose and may not be escaped there.
      */
     static const QChar encoderLaTeXProtectedTextOnlySymbols[];
-    static const int encoderLaTeXProtectedTextOnlySymbolsLen;
 
     /**
      * Check if input data contains a verbatim command like \url{...},
@@ -89,9 +95,9 @@ private:
 
     /**
      * Return a string that represents the part of
-     * the base string starting from startFrom containing
+     * the base string starting from startFrom contains
      * only alpha characters (a-z,A-Z).
-     * Return value may be an empty byte array.
+     * Return value may be an empty string.
      */
     QString readAlphaCharacters(const QString &base, int startFrom) const;
 
