@@ -914,7 +914,7 @@ void KBibTeXPart::elementViewDocumentMenu(QObject *obj)
     QString text = static_cast<QAction *>(obj)->data().toString(); ///< only a QAction will be passed along
 
     /// Guess mime type for url to open
-    QUrl url(text);
+    QUrl url{QUrl::fromUserInput(text)};
     QMimeType mimeType = FileInfo::mimeTypeForUrl(url);
     const QString mimeTypeName = mimeType.name();
     /// Ask KDE subsystem to open url in viewer matching mime type
