@@ -73,11 +73,6 @@ public:
         initialize();
     }
 
-    ~ValueListPrivate() {
-        delete comboboxFieldNames;
-        // TODO more deletes
-    }
-
     void setupGUI() {
         QBoxLayout *layout = new QVBoxLayout(p);
         layout->setMargin(0);
@@ -150,11 +145,9 @@ public:
     }
 
     void initialize() {
-        const BibTeXFields *bibtexFields = BibTeXFields::self();
-
         lineeditFilter->clear();
         comboboxFieldNames->clear();
-        for (const auto &fd : const_cast<const BibTeXFields &>(*bibtexFields)) {
+        for (const auto &fd : const_cast<const BibTeXFields &>(BibTeXFields::instance())) {
             if (!fd.upperCamelCaseAlt.isEmpty()) continue; /// keep only "single" fields and not combined ones like "Author or Editor"
             if (fd.upperCamelCase.startsWith('^')) continue; /// skip "type" and "id"
             comboboxFieldNames->addItem(fd.label, fd.upperCamelCase);
@@ -220,6 +213,7 @@ public:
         return (field.compare(Entry::ftAuthor, Qt::CaseInsensitive) == 0
                 || field.compare(Entry::ftEditor, Qt::CaseInsensitive) == 0
                 || field.compare(Entry::ftUrl, Qt::CaseInsensitive) == 0
+                || field.compare(Entry::ftFile, Qt::CaseInsensitive) == 0
                 || field.compare(Entry::ftLocalFile, Qt::CaseInsensitive) == 0
                 || field.compare(Entry::ftDOI, Qt::CaseInsensitive) == 0
                 || field.compare(Entry::ftKeywords, Qt::CaseInsensitive) == 0);
