@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2014 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
+ *   Copyright (C) 2004-2018 by Thomas Fischer <fischer@unix-ag.uni-kl.de> *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -12,7 +12,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, see <http://www.gnu.org/licenses/>.  *
+ *   along with this program; if not, see <https://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "documentlist.h"
@@ -23,24 +23,24 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPainter>
+#include <QPushButton>
 #include <QApplication>
+#include <QIcon>
+#include <QAction>
 
-#include <KDebug>
-#include <KLocale>
-#include <KGlobal>
-#include <KIcon>
-#include <KMimeType>
-#include <KAction>
+#include <KIconLoader>
+#include <KLocalizedString>
 #include <KActionMenu>
 #include <KDirOperator>
-#include <KPushButton>
 #include <KService>
 #include <KMessageBox>
 
-#include "kbibtexnamespace.h"
+#include "kbibtex.h"
 
 class DirOperatorWidget : public QWidget
 {
+    Q_OBJECT
+
 public:
     KDirOperator *dirOperator;
 
@@ -52,27 +52,27 @@ public:
         layout->setColumnStretch(1, 0);
         layout->setColumnStretch(2, 1);
 
-        KPushButton *buttonUp = new KPushButton(KIcon("go-up"), "", this);
+        QPushButton *buttonUp = new QPushButton(QIcon::fromTheme(QStringLiteral("go-up")), QString(), this);
         buttonUp->setToolTip(i18n("One level up"));
         layout->addWidget(buttonUp, 0, 0, 1, 1);
 
-        KPushButton *buttonHome = new KPushButton(KIcon("user-home"), "", this);
+        QPushButton *buttonHome = new QPushButton(QIcon::fromTheme(QStringLiteral("user-home")), QString(), this);
         buttonHome->setToolTip(i18n("Go to Home folder"));
         layout->addWidget(buttonHome, 0, 1, 1, 1);
 
-        dirOperator = new KDirOperator(KUrl("file:" + QDir::homePath()), this);
+        dirOperator = new KDirOperator(QUrl(QStringLiteral("file:") + QDir::homePath()), this);
         layout->addWidget(dirOperator, 1, 0, 1, 3);
         dirOperator->setView(KFile::Detail);
 
-        connect(buttonUp, SIGNAL(clicked()), dirOperator, SLOT(cdUp()));
-        connect(buttonHome, SIGNAL(clicked()), dirOperator, SLOT(home()));
+        connect(buttonUp, &QPushButton::clicked, dirOperator, &KDirOperator::cdUp);
+        connect(buttonHome, &QPushButton::clicked, dirOperator, &KDirOperator::home);
     }
 };
 
-DocumentListDelegate::DocumentListDelegate(OpenFileInfoManager *openFileInfoManager, QObject *parent)
-        : QStyledItemDelegate(parent), ofim(openFileInfoManager)
+DocumentListDelegate::DocumentListDelegate(QObject *parent)
+        : QStyledItemDelegate(parent)
 {
-    // nothing
+    /// nothing
 }
 
 void DocumentListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -80,7 +80,7 @@ void DocumentListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
     int height = option.rect.height();
 
     QStyle *style = QApplication::style();
-    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
+    style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 
     painter->save();
 
@@ -92,7 +92,7 @@ void DocumentListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
 
     OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(index.data(Qt::UserRole));
 
-    if (ofim->currentFile() == ofi) {
+    if (OpenFileInfoManager::instance().currentFile() == ofi) {
         /// for the currently open file, use a bold font to write file name
         QFont font = painter->font();
         font.setBold(true);
@@ -131,26 +131,22 @@ class DocumentListModel::DocumentListModelPrivate
 {
 public:
     OpenFileInfo::StatusFlag sf;
-    OpenFileInfoManager *ofim;
     OpenFileInfoManager::OpenFileInfoList ofiList;
 
-private:
-    // UNUSED DocumentListModel *p;
-
 public:
-    DocumentListModelPrivate(OpenFileInfo::StatusFlag statusFlag, OpenFileInfoManager *openFileInfoManager, DocumentListModel */* UNUSED parent*/)
-            : sf(statusFlag), ofim(openFileInfoManager)// UNUSED , p(parent)
+    DocumentListModelPrivate(OpenFileInfo::StatusFlag statusFlag, DocumentListModel *parent)
+            : sf(statusFlag)
     {
-        /// nothing
+        Q_UNUSED(parent)
     }
 };
 
-DocumentListModel::DocumentListModel(OpenFileInfo::StatusFlag statusFlag, OpenFileInfoManager *openFileInfoManager, QObject *parent)
-        : QAbstractListModel(parent), d(new DocumentListModel::DocumentListModelPrivate(statusFlag, openFileInfoManager, this))
+DocumentListModel::DocumentListModel(OpenFileInfo::StatusFlag statusFlag, QObject *parent)
+        : QAbstractListModel(parent), d(new DocumentListModel::DocumentListModelPrivate(statusFlag, this))
 {
     listsChanged(d->sf);
 
-    connect(openFileInfoManager, SIGNAL(flagsChanged(OpenFileInfo::StatusFlags)), this, SLOT(listsChanged(OpenFileInfo::StatusFlags)));
+    connect(&OpenFileInfoManager::instance(), &OpenFileInfoManager::flagsChanged, this, &DocumentListModel::listsChanged);
 }
 
 DocumentListModel::~DocumentListModel()
@@ -169,32 +165,59 @@ QVariant DocumentListModel::data(const QModelIndex &index, int role) const
     if (index.row() < 0 || index.row() >= rowCount()) return QVariant();
 
     OpenFileInfo *openFileInfo = d->ofiList[index.row()];
+    const QString iconName = openFileInfo->mimeType().replace(QLatin1Char('/'), QLatin1Char('-'));
 
     switch (role) {
     case Qt::DisplayRole: return openFileInfo->shortCaption();
     case Qt::DecorationRole: {
         /// determine mime type-based icon and overlays (e.g. for modified files)
         QStringList overlays;
-        QString iconName = openFileInfo->mimeType().replace(QLatin1Char('/'), QLatin1Char('-'));
         if (openFileInfo->flags().testFlag(OpenFileInfo::Favorite))
-            overlays << "favorites";
+            overlays << QStringLiteral("favorites");
         else
-            overlays << "";
+            overlays << QString();
         if (openFileInfo->flags().testFlag(OpenFileInfo::RecentlyUsed))
-            overlays << "document-open-recent";
+            overlays << QStringLiteral("document-open-recent");
         else
-            overlays << "";
+            overlays << QString();
         if (openFileInfo->flags().testFlag(OpenFileInfo::Open))
-            overlays << "folder-open";
+            overlays << QStringLiteral("folder-open");
         else
-            overlays << "";
+            overlays << QString();
         if (openFileInfo->isModified())
-            overlays << "document-save";
+            overlays << QStringLiteral("document-save");
         else
-            overlays << "";
-        return KIcon(iconName, NULL, overlays);
+            overlays << QString();
+        return KDE::icon(iconName, overlays, nullptr);
+    }
+    case Qt::ToolTipRole: {
+        QString htmlText(QString(QStringLiteral("<qt><img src=\"%1\"> <b>%2</b>")).arg(KIconLoader::global()->iconPath(iconName, KIconLoader::Small), openFileInfo->shortCaption()));
+        const QUrl url = openFileInfo->url();
+        if (url.isValid()) {
+            QString path(QFileInfo(url.path()).path());
+            if (!path.endsWith(QLatin1Char('/')))
+                path.append(QLatin1Char('/'));
+            htmlText.append(i18n("<br/><small>located in <b>%1</b></small>", path));
+        }
+        QStringList flagListItems;
+        if (openFileInfo->flags().testFlag(OpenFileInfo::Favorite))
+            flagListItems << i18n("Favorite");
+        if (openFileInfo->flags().testFlag(OpenFileInfo::RecentlyUsed))
+            flagListItems << i18n("Recently Used");
+        if (openFileInfo->flags().testFlag(OpenFileInfo::Open))
+            flagListItems << i18n("Open");
+        if (openFileInfo->isModified())
+            flagListItems << i18n("Modified");
+        if (!flagListItems.empty()) {
+            htmlText.append(QStringLiteral("<ul>"));
+            for (const QString &flagListItem : const_cast<const QStringList &>(flagListItems)) {
+                htmlText.append(QString(QStringLiteral("<li>%1</li>")).arg(flagListItem));
+            }
+            htmlText.append(QStringLiteral("</ul>"));
+        }
+        htmlText.append(QStringLiteral("</qt>"));
+        return htmlText;
     }
-    case Qt::ToolTipRole: return squeeze_text(openFileInfo->fullCaption(), 64);
     case Qt::UserRole: return qVariantFromValue(openFileInfo);
     default: return QVariant();
     }
@@ -210,7 +233,7 @@ void DocumentListModel::listsChanged(OpenFileInfo::StatusFlags statusFlags)
 {
     if (statusFlags.testFlag(d->sf)) {
         beginResetModel();
-        d->ofiList = d->ofim->filteredItems(d->sf);
+        d->ofiList = OpenFileInfoManager::instance().filteredItems(d->sf);
         endResetModel();
     }
 }
@@ -221,50 +244,50 @@ private:
     DocumentListView *p;
 
 public:
-    OpenFileInfoManager *ofim;
-    KAction *actionAddToFav, *actionRemFromFav;
-    KAction *actionCloseFile, *actionOpenFile;
+    QAction *actionAddToFav, *actionRemFromFav;
+    QAction *actionCloseFile, *actionOpenFile;
     KActionMenu *actionOpenMenu;
-    QList<KAction *> openMenuActions;
+    QList<QAction *> openMenuActions;
     KService::List openMenuServices;
     QSignalMapper openMenuSignalMapper;
 
-    DocumentListViewPrivate(DocumentListView *parent, OpenFileInfoManager *openFileInfoManager)
-            : p(parent), ofim(openFileInfoManager), actionAddToFav(NULL), actionRemFromFav(NULL), actionCloseFile(NULL), actionOpenFile(NULL) {
-        connect(&openMenuSignalMapper, SIGNAL(mapped(int)), p, SLOT(openFileWithService(int)));
+    DocumentListViewPrivate(DocumentListView *parent)
+            : p(parent), actionAddToFav(nullptr), actionRemFromFav(nullptr), actionCloseFile(nullptr), actionOpenFile(nullptr), actionOpenMenu(nullptr)
+    {
+        connect(&openMenuSignalMapper, static_cast<void(QSignalMapper::*)(int)>(&QSignalMapper::mapped), p, &DocumentListView::openFileWithService);
     }
 };
 
-DocumentListView::DocumentListView(OpenFileInfoManager *openFileInfoManager, OpenFileInfo::StatusFlag statusFlag, QWidget *parent)
-        : QListView(parent), d(new DocumentListViewPrivate(this, openFileInfoManager))
+DocumentListView::DocumentListView(OpenFileInfo::StatusFlag statusFlag, QWidget *parent)
+        : QListView(parent), d(new DocumentListViewPrivate(this))
 {
     setContextMenuPolicy(Qt::ActionsContextMenu);
-    setItemDelegate(new DocumentListDelegate(openFileInfoManager, this));
+    setItemDelegate(new DocumentListDelegate(this));
 
     if (statusFlag == OpenFileInfo::Open) {
-        d->actionCloseFile = new KAction(KIcon("document-close"), i18n("Close File"), this);
-        connect(d->actionCloseFile, SIGNAL(triggered()), this, SLOT(closeFile()));
+        d->actionCloseFile = new QAction(QIcon::fromTheme(QStringLiteral("document-close")), i18n("Close File"), this);
+        connect(d->actionCloseFile, &QAction::triggered, this, &DocumentListView::closeFile);
         addAction(d->actionCloseFile);
     } else {
-        d->actionOpenFile = new KAction(KIcon("document-open"), i18n("Open File"), this);
-        connect(d->actionOpenFile, SIGNAL(triggered()), this, SLOT(openFile()));
+        d->actionOpenFile = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open File"), this);
+        connect(d->actionOpenFile, &QAction::triggered, this, &DocumentListView::openFile);
         addAction(d->actionOpenFile);
     }
 
-    d->actionOpenMenu = new KActionMenu(KIcon("document-open"), i18n("Open with"), this);
+    d->actionOpenMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open with"), this);
     addAction(d->actionOpenMenu);
 
     if (statusFlag == OpenFileInfo::Favorite) {
-        d->actionRemFromFav = new KAction(KIcon("favorites"), i18n("Remove from Favorites"), this);
-        connect(d->actionRemFromFav, SIGNAL(triggered()), this, SLOT(removeFromFavorites()));
+        d->actionRemFromFav = new QAction(QIcon::fromTheme(QStringLiteral("favorites")), i18n("Remove from Favorites"), this);
+        connect(d->actionRemFromFav, &QAction::triggered, this, &DocumentListView::removeFromFavorites);
         addAction(d->actionRemFromFav);
     } else {
-        d->actionAddToFav = new KAction(KIcon("favorites"), i18n("Add to Favorites"), this);
-        connect(d->actionAddToFav, SIGNAL(triggered()), this, SLOT(addToFavorites()));
+        d->actionAddToFav = new QAction(QIcon::fromTheme(QStringLiteral("favorites")), i18n("Add to Favorites"), this);
+        connect(d->actionAddToFav, &QAction::triggered, this, &DocumentListView::addToFavorites);
         addAction(d->actionAddToFav);
     }
 
-    connect(this, SIGNAL(activated(QModelIndex)), this, SLOT(openFile()));
+    connect(this, &DocumentListView::activated, this, &DocumentListView::openFile);
 
     currentChanged(QModelIndex(), QModelIndex());
 }
@@ -297,7 +320,7 @@ void DocumentListView::openFile()
     QModelIndex modelIndex = currentIndex();
     if (modelIndex != QModelIndex()) {
         OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        d->ofim->setCurrentFile(ofi);
+        OpenFileInfoManager::instance().setCurrentFile(ofi);
     }
 }
 
@@ -306,8 +329,8 @@ void DocumentListView::openFileWithService(int i)
     QModelIndex modelIndex = currentIndex();
     if (modelIndex != QModelIndex()) {
         OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        if (!ofi->isModified() || (KMessageBox::questionYesNo(this, i18n("The current document has to be saved before switching the viewer/editor component."), i18n("Save before switching?"), KGuiItem(i18n("Save document"), KIcon("document-save")), KGuiItem(i18n("Do not switch"), KIcon("dialog-cancel"))) == KMessageBox::Yes && ofi->save()))
-            d->ofim->setCurrentFile(ofi, d->openMenuServices[i]);
+        if (!ofi->isModified() || (KMessageBox::questionYesNo(this, i18n("The current document has to be saved before switching the viewer/editor component."), i18n("Save before switching?"), KGuiItem(i18n("Save document"), QIcon::fromTheme(QStringLiteral("document-save"))), KGuiItem(i18n("Do not switch"), QIcon::fromTheme(QStringLiteral("dialog-cancel")))) == KMessageBox::Yes && ofi->save()))
+            OpenFileInfoManager::instance().setCurrentFile(ofi, d->openMenuServices[i]);
     }
 }
 
@@ -316,40 +339,41 @@ void DocumentListView::closeFile()
     QModelIndex modelIndex = currentIndex();
     if (modelIndex != QModelIndex()) {
         OpenFileInfo *ofi = qvariant_cast<OpenFileInfo *>(modelIndex.data(Qt::UserRole));
-        d->ofim->close(ofi);
+        OpenFileInfoManager::instance().close(ofi);
     }
 }
 
 void DocumentListView::currentChanged(const QModelIndex &current, const QModelIndex &)
 {
     bool hasCurrent = current != QModelIndex();
-    OpenFileInfo *ofi = hasCurrent ? qvariant_cast<OpenFileInfo *>(current.data(Qt::UserRole)) : NULL;
+    OpenFileInfo *ofi = hasCurrent ? qvariant_cast<OpenFileInfo *>(current.data(Qt::UserRole)) : nullptr;
     bool isOpen = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::Open) : false;
     bool isFavorite = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::Favorite) : false;
     bool hasName = hasCurrent ? ofi->flags().testFlag(OpenFileInfo::HasName) : false;
 
-    if (d->actionOpenFile != NULL)
+    if (d->actionOpenFile != nullptr)
         d->actionOpenFile->setEnabled(hasCurrent && !isOpen);
-    if (d->actionCloseFile != NULL)
+    if (d->actionCloseFile != nullptr)
         d->actionCloseFile->setEnabled(hasCurrent && isOpen);
-    if (d->actionAddToFav != NULL)
+    if (d->actionAddToFav != nullptr)
         d->actionAddToFav->setEnabled(hasCurrent && !isFavorite && hasName);
-    if (d->actionRemFromFav != NULL)
+    if (d->actionRemFromFav != nullptr)
         d->actionRemFromFav->setEnabled(hasCurrent && isFavorite);
 
-    foreach (KAction *action, d->openMenuActions)
+    for (QAction *action : const_cast<const QList<QAction *> &>(d->openMenuActions)) {
         d->actionOpenMenu->removeAction(action);
+    }
     d->openMenuServices.clear();
-    if (ofi != NULL) {
+    if (ofi != nullptr) {
         d->openMenuServices = ofi->listOfServices();
         int i = 0;
-        foreach (KService::Ptr servicePtr, d->openMenuServices) {
-            KAction *menuItem = new KAction(KIcon(servicePtr->icon()), servicePtr->name(), this);
+        for (KService::Ptr servicePtr : const_cast<const KService::List &>(d->openMenuServices)) {
+            QAction *menuItem = new QAction(QIcon::fromTheme(servicePtr->icon()), servicePtr->name(), this);
             d->actionOpenMenu->addAction(menuItem);
             d->openMenuActions << menuItem;
 
             d->openMenuSignalMapper.setMapping(menuItem, i);
-            connect(menuItem, SIGNAL(triggered()), &d->openMenuSignalMapper, SLOT(map()));
+            connect(menuItem, &QAction::triggered, &d->openMenuSignalMapper, static_cast<void(QSignalMapper::*)()>(&QSignalMapper::map));
             ++i;
         }
     }
@@ -364,30 +388,30 @@ public:
     DocumentListView *listFavorites;
     DirOperatorWidget *dirOperator;
 
-    DocumentListPrivate(OpenFileInfoManager *openFileInfoManager, DocumentList *p) {
-        listOpenFiles = new DocumentListView(openFileInfoManager, OpenFileInfo::Open, p);
-        DocumentListModel *model = new DocumentListModel(OpenFileInfo::Open, openFileInfoManager, listOpenFiles);
+    DocumentListPrivate(DocumentList *p) {
+        listOpenFiles = new DocumentListView(OpenFileInfo::Open, p);
+        DocumentListModel *model = new DocumentListModel(OpenFileInfo::Open, listOpenFiles);
         listOpenFiles->setModel(model);
-        p->addTab(listOpenFiles, KIcon("document-open"), i18n("Open Files"));
+        p->addTab(listOpenFiles, QIcon::fromTheme(QStringLiteral("document-open")), i18n("Open Files"));
 
-        listRecentFiles = new DocumentListView(openFileInfoManager, OpenFileInfo::RecentlyUsed, p);
-        model = new DocumentListModel(OpenFileInfo::RecentlyUsed, openFileInfoManager, listRecentFiles);
+        listRecentFiles = new DocumentListView(OpenFileInfo::RecentlyUsed, p);
+        model = new DocumentListModel(OpenFileInfo::RecentlyUsed, listRecentFiles);
         listRecentFiles->setModel(model);
-        p->addTab(listRecentFiles, KIcon("document-open-recent"), i18n("Recently Used"));
+        p->addTab(listRecentFiles, QIcon::fromTheme(QStringLiteral("document-open-recent")), i18n("Recently Used"));
 
-        listFavorites = new DocumentListView(openFileInfoManager, OpenFileInfo::Favorite, p);
-        model = new DocumentListModel(OpenFileInfo::Favorite, openFileInfoManager, listFavorites);
+        listFavorites = new DocumentListView(OpenFileInfo::Favorite, p);
+        model = new DocumentListModel(OpenFileInfo::Favorite, listFavorites);
         listFavorites->setModel(model);
-        p->addTab(listFavorites, KIcon("favorites"), i18n("Favorites"));
+        p->addTab(listFavorites, QIcon::fromTheme(QStringLiteral("favorites")), i18n("Favorites"));
 
         dirOperator = new DirOperatorWidget(p);
-        p->addTab(dirOperator,  KIcon("system-file-manager"), i18n("Filesystem Browser"));
-        connect(dirOperator->dirOperator, SIGNAL(fileSelected(KFileItem)), p, SLOT(fileSelected(KFileItem)));
+        p->addTab(dirOperator,  QIcon::fromTheme(QStringLiteral("system-file-manager")), i18n("Filesystem Browser"));
+        connect(dirOperator->dirOperator, &KDirOperator::fileSelected, p, &DocumentList::fileSelected);
     }
 };
 
-DocumentList::DocumentList(OpenFileInfoManager *openFileInfoManager, QWidget *parent)
-        : KTabWidget(parent), d(new DocumentListPrivate(openFileInfoManager, this))
+DocumentList::DocumentList(QWidget *parent)
+        : QTabWidget(parent), d(new DocumentListPrivate(this))
 {
     setDocumentMode(true);
 }
@@ -397,3 +421,5 @@ void DocumentList::fileSelected(const KFileItem &item)
     if (item.isFile() && item.isReadable())
         emit openFile(item.url());
 }
+
+#include "documentlist.moc"
